@@ -92,11 +92,17 @@ exports.BuildDeviceViewSelector = function(element) {
         }
     }
 
-    var selector = 
-        $('<select>', {
+    var insert_selector = false;
+    var selector = $('select', element);
+    if (selector.length == 0) { 
+        selector = $('<select>', {
             name: 'devices_views_select',
             id: 'devices_views_select'
         });
+        insert_selector = true;
+    } else { 
+        selector.empty();
+    }
 
     for (var i in grouped_views) {
         if (!Array.isArray(grouped_views[i])) {
@@ -126,19 +132,28 @@ exports.BuildDeviceViewSelector = function(element) {
     var selected_option = kismet.getStorage('kismet.ui.deviceview.selected', 'all');
     $('option[value="' + selected_option + '"]', selector).prop("selected", "selected");
 
-    selector.on("selectmenuselect", function(evt, elem) {
-        kismet.putStorage('kismet.ui.deviceview.selected', elem.item.value);
+    if (insert_selector) { 
+        element.append(selector);
+    }
 
-        if (device_dt != null) {
-            device_dt.ajax.url(local_uri_prefix + "devices/views/" + elem.item.value + "/devices.json");
-        }
-    });
+    try {
+        selector.selectmenu('refresh');
+    } catch (e) {
+        selector.selectmenu()
+            .selectmenu("menuWidget")
+            .addClass("selectoroverflow");
 
-    element.empty().append(selector);
+        selector.on("selectmenuselect", function(evt, elem) {
+            console.log("selected", elem.item.value);
+            kismet.putStorage('kismet.ui.deviceview.selected', elem.item.value);
+
+            if (device_dt != null) {
+                device_dt.ajax.url(local_uri_prefix + "devices/views/" + elem.item.value + "/devices.json");
+                ScheduleDeviceSummary();
+            }
+        });
+    }
 
-    selector.selectmenu()
-        .selectmenu("menuWidget")
-        .addClass("selectoroverflow");
 }
 
 // Local maps of views for phys and datasources we've already added
@@ -556,6 +571,8 @@ exports.DetailWindow = function(key, title, options, window_cb, close_cb) {
     }
 
     var panel = $.jsPanel({
+        theme: 'dark',
+
         id: dialogid,
         headerTitle: title,
 
@@ -670,7 +687,7 @@ exports.DeviceDetailWindow = function(key) {
                         .done(function(fulldata) {
                             fulldata = kismet.sanitizeObject(fulldata);
 
-                            panel.headerTitle("Device: " + kismet.censorMAC(fulldata['kismet.device.base.commonname']));
+                            panel.headerTitle("Device: " + kismet.censorString(fulldata['kismet.device.base.commonname']));
 
                             var accordion = $('div#accordion', content);
 
@@ -845,6 +862,7 @@ exports.HealthCheck = function() {
             .fail(function() {
                 if (exports.connection_error >= 3 && exports.connection_error_panel == null) {
                     exports.connection_error_panel = $.jsPanel({
+                        theme: 'dark',
                         id: "connection-alert",
                         headerTitle: 'Cannot Connect to Kismet',
                         headerControls: {
@@ -954,13 +972,17 @@ exports.renderTemperature = function(c, precision = 5) {
     }
 }
 
-var deviceTid;
+var deviceTid = -1;
 
+var devicetableHolder = null;
 var devicetableElement = null;
 
 function ScheduleDeviceSummary() {
+    if (deviceTid != -1)
+        clearTimeout(deviceTid);
+
     try {
-        if (exports.window_visible && devicetableElement.is(":visible")) {
+        if (devicetableElement != null && exports.window_visible && devicetableElement.is(":visible")) {
 
             var dt = devicetableElement.DataTable();
 
@@ -969,21 +991,11 @@ function ScheduleDeviceSummary() {
             kismet.putStorage('kismet.base.devicetable.order', JSON.stringify(dt.order()));
             kismet.putStorage('kismet.base.devicetable.search', JSON.stringify(dt.search()));
 
-            // Snapshot where we are, because the 'don't reset page' in ajax.reload
-            // DOES still reset the scroll position
-            var prev_pos = {
-                'top': $(dt.settings()[0].nScrollBody).scrollTop(),
-                'left': $(dt.settings()[0].nScrollBody).scrollLeft()
-            };
-            dt.ajax.reload(function(d) {
-                // Restore our scroll position
-                $(dt.settings()[0].nScrollBody).scrollTop( prev_pos.top );
-                $(dt.settings()[0].nScrollBody).scrollLeft( prev_pos.left );
-            }, false);
+            dt.ajax.reload(function(d) { }, false);
         }
 
     } catch (error) {
-        ;
+        console.log(error);
     }
     
     // Set our timer outside of the datatable callback so that we get called even
@@ -999,8 +1011,8 @@ function CancelDeviceSummary() {
 
 /* Create the device table */
 exports.CreateDeviceTable = function(element) {
-    devicetableElement = element;
-    var statuselement = $('#' + element.attr('id') + '_status');
+    // devicetableElement = element;
+    // var statuselement = $('#' + element.attr('id') + '_status');
 
     var dt = exports.InitializeDeviceTable(element);
 
@@ -1010,9 +1022,12 @@ exports.CreateDeviceTable = function(element) {
     ScheduleDeviceSummary();
 }
 
-exports.InitializeDeviceTable = function(element) {
-    var statuselement = $('#' + element.attr('id') + '_status');
+/* Activate the device table & do something */
+exports.ActivateDeviceTable = function() { 
+    exports.InitializeDeviceTable(devicetableHolder);
+}
 
+exports.InitializeDeviceTable = function(element) {
     /* Make the fields list json and set the wrapper object to aData to make the DT happy */
     var cols = exports.GetDeviceColumns();
     var colmap = exports.GetDeviceColumnMap(cols);
@@ -1024,40 +1039,43 @@ exports.InitializeDeviceTable = function(element) {
         datatable: true,
     };
 
-    if ($.fn.dataTable.isDataTable(element)) {
-        element.DataTable().destroy();
+    devicetableHolder = element;
+
+    if (devicetableElement != null && $.fn.dataTable.isDataTable(devicetableElement)) {
+        devicetableElement.DataTable().clear().destroy();
         element.empty();
     }
 
-    element
-        .on('xhr.dt', function (e, settings, json, xhr) {
-            json = kismet.sanitizeObject(json);
+    if ($('#devices', element).length == 0) { 
+        devicetableElement =
+            $('<table>', {
+                id: 'devices-table',
+                class: 'fixeddt stripe hover nowrap pageResize',
+                'cell-spacing': 0,
+                width: '100%',
+            });
+        element.append(devicetableElement);
+    }
 
-            if (json['recordsFiltered'] != json['recordsTotal'])
-                statuselement.html(json['recordsTotal'] + " devices (" + json['recordsFiltered'] + " shown after filter)");
-            else
-                statuselement.html(json['recordsTotal'] + " devices");
-        } )
+    device_dt = devicetableElement
         .DataTable( {
 
         destroy: true,
 
         scrollResize: true,
-        scrollY: 200,
         scrollX: "100%",
 
+        pageResize: true,
         serverSide: true,
         processing: true,
 
-        dom: '<"viewselector">ft',
+        // stateSave: true,
+
+        dom: '<"viewselector">ftip',
 
         deferRender: true,
         lengthChange: false,
 
-        scroller: {
-            loadingIndicator: true,
-        },
-
         // Create a complex post to get our summary fields only
         ajax: {
             url: local_uri_prefix + "devices/views/" + kismet.getStorage('kismet.ui.deviceview.selected', 'all') + "/devices.json",
@@ -1133,8 +1151,12 @@ exports.InitializeDeviceTable = function(element) {
 
     });
 
-    device_dt = element.DataTable();
+    // device_dt = element.DataTable();
     // var dt_base_height = element.height();
+
+    try { 
+        device_dt.stateRestore.state.add("AJAX");
+    } catch (_err) { }
     
     // $('div.viewselector').html("View picker");
     exports.BuildDeviceViewSelector($('div.viewselector'));
@@ -1193,12 +1215,14 @@ exports.ResizeDeviceTable = function(element) {
 
 exports.ResetDeviceTable = function(element) {
     CancelDeviceSummary();
-
     exports.InitializeDeviceTable(element);
-
     ScheduleDeviceSummary();
 }
 
+exports.ResetExistingDeviceTable = function() {
+    exports.ResetDeviceTable(devicetableHolder);
+}
+
 kismet_ui_settings.AddSettingsPane({
     id: 'core_devicelist_columns',
     listTitle: 'Device List Columns',
@@ -1349,7 +1373,7 @@ kismet_ui_settings.AddSettingsPane({
         });
 
         kismet.putStorage('kismet.datatable.columns', col_defs);
-        exports.ResetDeviceTable(devicetableElement);
+        exports.ResetDeviceTable(devicetableHolder);
     },
 });
 
